# The Geniverse API
Open source library to access creative uses of generative AI models such as VQGAN. For now you can generate images from prompts, interpolate and create infinite zooms with your results. 
